#include <M5StickC.h>
#include <ArduinoBLE.h>

// BLE UUIDs
#define SERVICE_UUID "20FCB58A-DA3E-43F4-BAA2-49634549A395"
#define UUID_AX "20FCB58B-DA3E-43F4-BAA2-49634549A395"
#define UUID_AY "20FCB58C-DA3E-43F4-BAA2-49634549A395"
#define UUID_AZ "20FCB58D-DA3E-43F4-BAA2-49634549A395"

// BLE Service
BLEService myService(SERVICE_UUID); 

// BLE Characteristics
BLEFloatCharacteristic chAX(UUID_AX, BLERead | BLENotify);
BLEFloatCharacteristic chAY(UUID_AY, BLERead | BLENotify);
BLEFloatCharacteristic chAZ(UUID_AZ, BLERead | BLENotify);

void setup() 
{
  M5.begin();
  M5.IMU.Init();
  Serial.begin(115200);
  
  // Initialize BLE
  if (!BLE.begin()) 
  {
    Serial.println("BLE: failed");
    M5.Lcd.println("BLE: failed");
    while(1);
  }
  Serial.println("BLE: ok");
  M5.Lcd.println("BLE: ok");

  // Set BLE name
  BLE.setLocalName("Vibsens-DataLogger");
  BLE.setDeviceName("Vibsens"); 
  
  // Set advertised Service
  BLE.setAdvertisedService(myService);
  
  // Add characteristics to the Service
  myService.addCharacteristic(chAX);
  myService.addCharacteristic(chAY);
  myService.addCharacteristic(chAZ);
  
  // Add service to BLE
  BLE.addService(myService);
  
  // Start advertising
  BLE.advertise();
  Serial.println("Advertising started");
  Serial.println("Bluetooth device active, waiting for connections...");
  M5.Lcd.println("Advertising started");
  M5.Lcd.println("Bluetooth device active, waiting for connections...");

  // Rotate the screen display
  M5.Lcd.setRotation(2); // Change the rotation value as needed (0, 1, 2, or 3 for 0°, 90°, 180°, and 270° respectively)
}

void loop() 
{
  // Read accelerometer values from M5StickC
  float accX, accY, accZ;
  M5.IMU.getAccelData(&accX, &accY, &accZ);
  
  // Modify accZ by subtracting 1
  float accZZ = accZ - 1.0f;

  // Update BLE characteristics with accelerometer values
  chAX.writeValue(accX);
  chAY.writeValue(accY);
  chAZ.writeValue(accZZ);  // Use the adjusted accZ value 

  // Print values to serial monitor
  Serial.print("Ax: ");
  Serial.print(accX);
  Serial.print(", Ay: ");
  Serial.print(accY);
  Serial.print(", Az: ");
  Serial.println(accZZ);  // Print the adjusted accZ value 

  // Print values to M5StickC display
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print("Ax: ");
  M5.Lcd.print(accX);
  M5.Lcd.setCursor(0, 20);
  M5.Lcd.print("Ay: ");
  M5.Lcd.print(accY);
  M5.Lcd.setCursor(0, 40);
  M5.Lcd.print("Az: ");
  M5.Lcd.print(accZZ); // Display the adjusted accZ value 

  // Delay for stability
  delay(100);
}
